Mpmc

Struct Mpmc 

pub struct Mpmc<T, const N: usize, const MP: usize, const MC: usize> { /* private fields */ }

Implementations

Source

impl<T, const N: usize, const MP: usize, const MC: usize> Mpmc<T, N, MP, MC>

pub const fn new() -> Self

pub const fn sender(&self) -> Sender<'_, T, N, MP, MC>

pub const fn recver(&self) -> Receiver<'_, T, N, MP, MC>

Methods from Deref<Target = Ring<T, N, MP, MC>>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn try_push(&self, val: T) -> Result<(), Error<T>>

Appends an element to the back of the Ring.

Returns Err if the Ring is full or in critical section.

pub async fn push(&self, val: T)

Appends an element to the back of the Ring.

pub fn try_pop(&self) -> Result<T, Error<()>>

Removes the first element and returns it.

Returns Err if the Ring is empty or in critical section.

pub async fn pop(&self) -> T

Removes the first element and returns it.