pub struct Mpmc<T, const N: usize, const MP: usize, const MC: usize> { /* private fields */ }Implementations
Methods from Deref<Target = Ring<T, N, MP, MC>>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn try_push(&self, val: T) -> Result<(), Error<T>>
pub fn try_push(&self, val: T) -> Result<(), Error<T>>
Appends an element to the back of the Ring.
Returns Err if the Ring is full or in critical section.